@@ -36,6 +36,9 @@ var Events = map[string]string{
 	"customer.subscription.created":            "triggers/customer.subscription.created.json",
 	"customer.subscription.deleted":            "triggers/customer.subscription.deleted.json",
 	"customer.subscription.updated":            "triggers/customer.subscription.updated.json",
+	"identity.verification_session.canceled":   "triggers/identity.verification_session.canceled.json",
+	"identity.verification_session.created":    "triggers/identity.verification_session.created.json",
+	"identity.verification_session.redacted":   "triggers/identity.verification_session.redacted.json",
 	"invoice.created":                          "triggers/invoice.created.json",
 	"invoice.finalized":                        "triggers/invoice.finalized.json",
 	"invoice.paid":                             "triggers/invoice.paid.json",
@@ -76,6 +79,8 @@ var Events = map[string]string{
 	"subscription_schedule.created":            "triggers/subscription_schedule.created.json",
 	"subscription_schedule.released":           "triggers/subscription_schedule.released.json",
 	"subscription_schedule.updated":            "triggers/subscription_schedule.updated.json",
+	"subscription.payment_succeeded":           "triggers/subscription.payment_succeeded.json",
+	"subscription.payment_failed":              "triggers/subscription.payment_failed.json",
 	"quote.created":                            "triggers/quote.created.json",
 	"quote.canceled":                           "triggers/quote.canceled.json",
 	"quote.finalized":                          "triggers/quote.finalized.json",
@@ -83,7 +88,7 @@ var Events = map[string]string{
 }
 
 // BuildFromFixtureFile creates a new fixture struct for a file
-func BuildFromFixtureFile(fs afero.Fs, apiKey, stripeAccount, apiBaseURL, jsonFile string, skip, override, add, remove []string) (*Fixture, error) {
+func BuildFromFixtureFile(fs afero.Fs, apiKey, stripeAccount, apiBaseURL, jsonFile string, skip, override, add, remove []string, edit bool) (*Fixture, error) {
 	fixture, err := NewFixtureFromFile(
 		fs,
 		apiKey,
@@ -94,6 +99,7 @@ func BuildFromFixtureFile(fs afero.Fs, apiKey, stripeAccount, apiBaseURL, jsonFi
 		override,
 		add,
 		remove,
+		edit,
 	)
 	if err != nil {
 		return nil, err
@@ -134,7 +140,7 @@ func EventNames() []string {
 }
 
 // Trigger triggers a Stripe event.
-func Trigger(ctx context.Context, event string, stripeAccount string, baseURL string, apiKey string, skip, override, add, remove []string, raw string, apiVersion string) ([]string, error) {
+func Trigger(ctx context.Context, event string, stripeAccount string, baseURL string, apiKey string, skip, override, add, remove []string, raw string, apiVersion string, edit bool) ([]string, error) {
 	var fixture *Fixture
 	var err error
 	fs := afero.NewOsFs()
@@ -147,7 +153,7 @@ func Trigger(ctx context.Context, event string, stripeAccount string, baseURL st
 
 	if len(raw) == 0 {
 		if file, ok := Events[event]; ok {
-			fixture, err = BuildFromFixtureFile(fs, apiKey, stripeAccount, baseURL, file, skip, override, add, remove)
+			fixture, err = BuildFromFixtureFile(fs, apiKey, stripeAccount, baseURL, file, skip, override, add, remove, edit)
 			if err != nil {
 				return nil, err
 			}
@@ -157,7 +163,7 @@ func Trigger(ctx context.Context, event string, stripeAccount string, baseURL st
 				return nil, fmt.Errorf(fmt.Sprintf("The event ‘%s’ is not supported by the Stripe CLI.", event))
 			}
 
-			fixture, err = BuildFromFixtureFile(fs, apiKey, stripeAccount, baseURL, event, skip, override, add, remove)
+			fixture, err = BuildFromFixtureFile(fs, apiKey, stripeAccount, baseURL, event, skip, override, add, remove, edit)
 			if err != nil {
 				return nil, err
 			}
