@@ -119,6 +119,10 @@ func RefreshPluginManifest(ctx context.Context, config config.IConfig, fs afero.
 		return err
 	}
 
+	if err := validatePluginManifest(body); err != nil {
+		return err
+	}
+
 	configPath := config.GetConfigFolder(os.Getenv("XDG_CONFIG_HOME"))
 	pluginManifestPath := filepath.Join(configPath, "plugins.toml")
 
@@ -131,6 +135,18 @@ func RefreshPluginManifest(ctx context.Context, config config.IConfig, fs afero.
 	return nil
 }
 
+func validatePluginManifest(body []byte) error {
+	var manifestBody PluginList
+
+	if err := toml.Unmarshal(body, &manifestBody); err != nil {
+		return fmt.Errorf("Received an invalid plugin manifest. Error: %s", err)
+	}
+	if len(manifestBody.Plugins) == 0 {
+		return fmt.Errorf("Received an empty plugin manifest")
+	}
+	return nil
+}
+
 // AddEntryToPluginManifest update plugins.toml with a new release version
 func AddEntryToPluginManifest(ctx context.Context, config config.IConfig, fs afero.Fs, entry Plugin) error {
 	color := ansi.Color(os.Stdout)
